@@ -2,26 +2,24 @@ package CPAN::Digger;
 use strict;
 use warnings FATAL => 'all';
 
-our $VERSION = '1.02';
+our $VERSION = '1.03';
 
 use Capture::Tiny qw(capture);
-use Log::Log4perl ();
-use File::Temp qw(tempdir);
 use Cwd qw(getcwd);
-use Exporter qw(import);
-use LWP::UserAgent ();
 use Data::Dumper qw(Dumper);
+use Exporter qw(import);
 use File::Spec ();
+use File::Temp qw(tempdir);
 use Log::Log4perl ();
-use Log::Log4perl::Level ();
+use LWP::UserAgent ();
 use MetaCPAN::Client ();
 
 
 use CPAN::Digger::DB qw(get_fields);
 
-my $tempdir = tempdir( CLEANUP => 1 );
+my $tempdir = tempdir( CLEANUP => ($ENV{KEEP_TEMPDIR} ? 0 : 1) );
 
-my %known_licenses = map {$_ => 1} qw(perl_5);
+my %known_licenses = map {$_ => 1} qw(apache_2_0 artistic_2 bsd gpl_3 lgpl_2_1 lgpl_3_0 perl_5); # open_source, unknown
 
 sub new {
     my ($class, %args) = @_;
@@ -30,6 +28,7 @@ sub new {
         $self->{$key} = $args{$key};
     }
     $self->{log} = uc $self->{log};
+    $self->{check_github} = delete $self->{github};
 
     $self->{db} = CPAN::Digger::DB->new(db => $self->{db});
 
@@ -66,12 +65,22 @@ sub get_data {
         distribution => $item->distribution,
         version      => $item->version,
         author       => $item->author,
+        date         => $item->date,
     );
+    #die Dumper $item;
 
     $logger->debug('dist: ', $item->distribution);
     $logger->debug('      ', $item->author);
-    #my @licenses = @{ $item->license };
-    #$logger->debug('      ', join ' ', @licenses);
+    my @licenses = @{ $item->license };
+    $data{licenses} = join ' ', @licenses;
+    $logger->debug('      ',  $data{licenses});
+    for my $license (@licenses) {
+        if ($license eq 'unknown') {
+            $logger->error("Unknown license '$license'");
+        } elsif (not exists $known_licenses{$license}) {
+            $logger->warn("Unknown license '$license'. Probably CPAN::Digger needs to be updated");
+        }
+    }
     # if there are not licenses =>
     # if there is a license called "unknonws"
     # check against a known list of licenses (grow it later, or look it up somewhere?)
@@ -83,12 +92,9 @@ sub get_data {
             $data{vcs_url} = $vcs_url;
             $data{vcs_name} = $vcs_name;
             $logger->debug("      $vcs_name: $vcs_url");
-            if ($self->{github} and $vcs_name eq 'GitHub') {
-                analyze_github(\%data);
-            }
         }
     } else {
-        $logger->warn('No repository for ', $item->distribution);
+        $logger->error('No repository for ', $item->distribution);
     }
     return %data;
 }
@@ -102,21 +108,20 @@ sub analyze_github {
     my $repo_name = (split '\/', $vcs_url)[-1];
     $logger->info("Analyze GitHub repo '$vcs_url' in directory $repo_name");
 
-    my $ua = LWP::UserAgent->new(timeout => 5, max_redirect => 0);
+    my $ua = LWP::UserAgent->new(timeout => 5);
     my $response = $ua->get($vcs_url);
-    if ($response->status_line eq '404 Not Found') {
+    my $status_line = $response->status_line;
+    if ($status_line eq '404 Not Found') {
         $logger->error("Repository '$vcs_url' Received 404 Not Found. Please update the link in the META file");
         return;
     }
-    if ($response->status_line eq '301 Moved Permanently') {
-        $logger->error("Repository '$vcs_url' is being redirected. Please update the link in the META file");
-        return;
-    }
-    my $status_line = $response->status_line;
-    if ($response->status_line ne '200 OK') {
+    if ($response->code != 200) {
         $logger->error("Repository '$vcs_url'  got a response of '$status_line'. Please report this to the maintainer of CPAN::Digger.");
         return;
     }
+    if ($response->redirects) {
+        $logger->error("Repository '$vcs_url' is being redirected. Please update the link in the META file");
+    }
 
     my $git = 'git';
 
@@ -128,6 +133,7 @@ sub analyze_github {
     };
     chdir($cwd);
     my $repo = "$tempdir/$repo_name";
+    $logger->debug("REPO path '$repo'");
 
     if ($exit_code != 0) {
         # TODO capture stderr and include in the log
@@ -136,12 +142,16 @@ sub analyze_github {
     }
 
     $data->{travis} = -e "$repo/.travis.yml";
-    $data->{github_actions} = scalar(glob("$repo/.github/workflows/*"));
+    my @ga = glob("$repo/.github/workflows/*");
+    $data->{github_actions} = (scalar(@ga) ? 1 : 0);
     $data->{circleci} = -e "$repo/.circleci";
     $data->{appveyor} = (-e "$repo/.appveyor.yml") || (-e "$repo/appveyor.yml");
+    $data->{azure_pipelines} = -e "$repo/azure-pipelines.yml";
 
     for my $ci (qw(travis github_actions circleci appveyor)) {
+        $logger->debug("Is CI '$ci'?");
         if ($data->{$ci}) {
+            $logger->debug("CI '$ci' found!");
             $data->{has_ci} = 1;
         }
     }
@@ -150,10 +160,17 @@ sub analyze_github {
 sub collect {
     my ($self) = @_;
 
+    my @all_the_distributions;
+
     my $log_level = $self->{log}; # TODO: shall we validate?
-    Log::Log4perl->easy_init(Log::Log4perl::Level::to_priority( $log_level ));
+    Log::Log4perl->easy_init({
+        level => $log_level,
+        layout   => '%d{yyyy-MM-dd HH:mm:ss} - %p - %m%n',
+    });
+
     my $logger = Log::Log4perl->get_logger();
     $logger->info('Starting');
+    $logger->info("Tempdir: $tempdir");
     $logger->info("Recent: $self->{recent}") if $self->{recent};
     $logger->info("Author: $self->{author}") if $self->{author};
 
@@ -166,6 +183,7 @@ sub collect {
     } else {
         $rset  = $mcpan->recent($self->{recent});
     }
+    $logger->info("MetaCPAN::Client::ResultSet received with a total of $rset->{total} items");
     my %distros;
     my @fields = get_fields();
     while ( my $item = $rset->next ) {
@@ -175,18 +193,46 @@ sub collect {
             my $row = $self->{db}->db_get_distro($item->distribution);
             next if $row and $row->{version} eq $item->version; # we already have this in the database (shall we call last?)
             my %data = $self->get_data($item);
-            #say Dumper %data;
+            #die Dumper \%data;
             $self->{db}->db_insert_into(@data{@fields});
-            sleep $self->{sleep} if $self->{sleep};
+            push @all_the_distributions, \%data;
     }
 
+    if ($self->{author}) {
+        @all_the_distributions = reverse sort {$a->{date} cmp $b->{date}} @all_the_distributions;
+        if ($self->{limit} and @all_the_distributions > $self->{limit}) {
+            @all_the_distributions = @all_the_distributions[0 .. $self->{limit}-1];
+        }
+    }
+
+    # Check on the VCS
+    if ($self->{check_github}) {
+        $logger->info("Starting to check GitHub");
+        for my $data (@all_the_distributions) {
+            my $distribution = $data->{distribution};
+            my $data_ref = $self->{db}->db_get_distro($distribution);
+            next if not $data_ref->{vcs_name};
+
+            if ($self->{check_github} and $data_ref->{vcs_name} eq 'GitHub') {
+                analyze_github($data_ref);
+            }
+            my %data = %$data_ref;
+            $self->{db}->db_update($distribution, @data{@fields});
+            sleep $self->{sleep} if $self->{sleep};
+        }
+    }
+
+
     if ($self->{report}) {
         #print "Text report\n";
-        my $distros = $self->{db}->db_get_every_distro();
-        for my $distro (@$distros) {
+        my @distros = @{ $self->{db}->db_get_every_distro() };
+        if ($self->{limit} and @distros > $self->{limit}) {
+            @distros = @distros[0 .. $self->{limit}-1];
+        }
+        for my $distro (@distros) {
             #die Dumper $distro;
-            printf "%-40s %-7s", $distro->{distribution}, ($distro->{vcs_url} ? '' : 'NO VCS');
-            if ($self->{github}) {
+            printf "%s %-40s %-7s", $distro->{date}, $distro->{distribution}, ($distro->{vcs_url} ? '' : 'NO VCS');
+            if ($self->{check_github}) {
                 printf "%-7s", ($distro->{has_ci} ? '' : 'NO CI');
             }
             print "\n";
