@@ -2,7 +2,7 @@ package CPAN::Digger::CLI;
 use strict;
 use warnings FATAL => 'all';
 
-our $VERSION = '1.02';
+our $VERSION = '1.03';
 
 use Getopt::Long qw(GetOptions);
 
@@ -14,10 +14,12 @@ sub run {
         author => undef,
         github => undef,
         recent => undef,
-        log    => 'OFF',
+        log    => 'INFO',
         help   => undef,
         sleep  => 0,
         db     => undef,
+        version => undef,
+        limit   => undef,
     );
 
     GetOptions(
@@ -25,34 +27,44 @@ sub run {
         'author=s',
         'db=s',
         'recent=i',
+        'limit=i',
         'sleep=i',
         'github',
         'log=s',
         'report',
         'help',
+        'version',
     ) or usage();
     usage() if $args{help};
+    if ($args{version}) {
+        print "CPAN::Digger VERSION $VERSION\n";
+        exit();
+    }
     usage() if not ($args{author} xor $args{recent});
 
+
     my $cd = CPAN::Digger->new(%args);
     $cd->collect();
 }
 
 
 sub usage {
-    die qq{Usage: $0
+    die qq{CPAN::Digger VERSION $VERSION
+
+Usage: $0
     Required exactly one of them:
        --recent N         (Number of the most recent packages to check)
        --author PAUSEID
 
        --report           (Show text report at the end of processing.)
-       --log LEVEL        [ALL, TRACE, DEBUG, INFO, WARN, ERROR, FATAL, OFF] (default is OFF)
+       --log LEVEL        [ALL, TRACE, DEBUG, INFO, WARN, ERROR, FATAL, OFF] (default is INFO)
 
        --github           Fetch information from github
        --sleep SECONDS    (Wait time between git clone operations, defaults to 0)
 
        --db PATH          (path to SQLite database file, if not supplied using in-memory database)
 
+       --version
        --help
 
     Sample usage for authors:
