@@ -2,17 +2,17 @@ package CPAN::Digger::DB;
 use strict;
 use warnings FATAL => 'all';
 
-our $VERSION = '1.02';
+our $VERSION = '1.03';
 
 use DBI;
-use FindBin ();
-use Path::Tiny qw(path);
 use Exporter qw(import);
 use File::HomeDir ();
+use FindBin ();
+use Path::Tiny qw(path);
 
 our @EXPORT_OK = qw(get_fields);
 
-my @fields = qw(distribution version author vcs_url vcs_name travis github_actions appveyor circleci has_ci);
+my @fields = qw(distribution version author date vcs_url vcs_name travis github_actions appveyor circleci has_ci license issues azure_pipelines);
 sub get_fields {
     return @fields;
 }
@@ -28,11 +28,11 @@ sub new {
 
     my $dbh = $self->{dbh} = $self->get_db();
     $self->{sth_get_distro} = $dbh->prepare('SELECT * FROM dists WHERE distribution=?');
-    $self->{sth_get_every_distro} = $dbh->prepare('SELECT * FROM dists');
+    $self->{sth_get_every_distro} = $dbh->prepare('SELECT * FROM dists ORDER by date DESC');
     my $fields = join ', ', @fields;
     my $places = join ', ', ('?') x scalar @fields;
     $self->{sth_insert} = $dbh->prepare("INSERT INTO dists ($fields) VALUES ($places)");
-
+    $self->{sth_delete} = $dbh->prepare("DELETE FROM dists WHERE distribution=?");
     return $self;
 }
 
@@ -67,6 +67,14 @@ sub db_insert_into {
     $self->{sth_insert}->execute(@params);
 }
 
+# TODO have an update here?
+sub db_update {
+    my ($self, $distribution, @params) = @_;
+    $self->{sth_delete}->execute($distribution);
+    $self->{sth_insert}->execute(@params);
+}
+
+
 sub db_get_distro {
     my ($self, $distribution) = @_;
 
@@ -91,13 +99,17 @@ sub db_get_every_distro {
 __DATA__
 CREATE TABLE dists (
     distribution VARCHAR(255) NOT NULL UNIQUE,
+    date         VARCHAR(255),
     version      VARCHAR(255),
     author       VARCHAR(255),
+    license      VARCHAR(255),
+    issues       VARCHAR(255),
     vcs_url      VARCHAR(255),
     vcs_name     VARCHAR(255),
     appveyor         BOOLEAN,
     circleci         BOOLEAN,
     travis           BOOLEAN,
     github_actions   BOOLEAN,
+    azure_pipelines  BOOLEAN,
     has_ci           BOOLEAN
 );
